summaryrefslogtreecommitdiffstats
path: root/filters/kspread/excel
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-15 15:32:11 -0600
committerTimothy Pearson <[email protected]>2011-12-15 15:32:11 -0600
commit94844816550ad672ccfcdc25659c625546239998 (patch)
treee35fc60fd736c645d59f6408af032774ad8023d3 /filters/kspread/excel
parent2a811c38c74c03648ecf857e566c44483cbad706 (diff)
downloadkoffice-94844816550ad672ccfcdc25659c625546239998.tar.gz
koffice-94844816550ad672ccfcdc25659c625546239998.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'filters/kspread/excel')
-rw-r--r--filters/kspread/excel/excelexport.cc16
-rw-r--r--filters/kspread/excel/excelexport.h16
-rw-r--r--filters/kspread/excel/import/excelimport.cc28
-rw-r--r--filters/kspread/excel/import/excelimport.h2
-rw-r--r--filters/kspread/excel/sidewinder/excel.cpp64
-rw-r--r--filters/kspread/excel/sidewinder/excel.h16
-rw-r--r--filters/kspread/excel/sidewinder/format.cpp28
-rw-r--r--filters/kspread/excel/sidewinder/format.h36
-rw-r--r--filters/kspread/excel/sidewinder/pole.cpp24
-rw-r--r--filters/kspread/excel/sidewinder/ustring.cpp4
-rw-r--r--filters/kspread/excel/sidewinder/ustring.h4
11 files changed, 119 insertions, 119 deletions
diff --git a/filters/kspread/excel/excelexport.cc b/filters/kspread/excel/excelexport.cc
index 2e2c50e7..0ecf41f7 100644
--- a/filters/kspread/excel/excelexport.cc
+++ b/filters/kspread/excel/excelexport.cc
@@ -13,7 +13,7 @@ ExcelExport::ExcelExport(KoFilter *, const char *, const TQStringList&) : KoFilt
}
-KoFilter::ConversiontqStatus ExcelExport::convert(const TQCString& from, const TQCString& to) {
+KoFilter::ConversionStatus ExcelExport::convert(const TQCString& from, const TQCString& to) {
// Double check that's we really what we want to do
if ( ( (to != "application/excel") && (to != "application/msexcel") ) || from != "application/x-kspread") {
kdWarning(0) << "Invalid mimetypes " << to << ", " << from << endl;
@@ -28,37 +28,37 @@ KoFilter::ConversiontqStatus ExcelExport::convert(const TQCString& from, const T
/*
-KoFilter::ConversiontqStatus ExcelWorker::startDocument(KSpreadFilterProperty property) {
+KoFilter::ConversionStatus ExcelWorker::startDocument(KSpreadFilterProperty property) {
return KoFilter::OK;
}
-KoFilter::ConversiontqStatus ExcelWorker::startInfoLog(KSpreadFilterProperty property) {
+KoFilter::ConversionStatus ExcelWorker::startInfoLog(KSpreadFilterProperty property) {
return KoFilter::OK;
}
-KoFilter::ConversiontqStatus ExcelWorker::startInfoAuthor(KSpreadFilterProperty property) {
+KoFilter::ConversionStatus ExcelWorker::startInfoAuthor(KSpreadFilterProperty property) {
return KoFilter::OK;
}
-KoFilter::ConversiontqStatus ExcelWorker::startInfoAbout(KSpreadFilterProperty property) {
+KoFilter::ConversionStatus ExcelWorker::startInfoAbout(KSpreadFilterProperty property) {
return KoFilter::OK;
}
-KoFilter::ConversiontqStatus ExcelWorker::startSpreadBook(KSpreadFilterProperty property) {
+KoFilter::ConversionStatus ExcelWorker::startSpreadBook(KSpreadFilterProperty property) {
return KoFilter::OK;
}
-KoFilter::ConversiontqStatus ExcelWorker::startSpreadSheet(KSpreadFilterProperty property) {
+KoFilter::ConversionStatus ExcelWorker::startSpreadSheet(KSpreadFilterProperty property) {
return KoFilter::OK;
}
-KoFilter::ConversiontqStatus ExcelWorker::startSpreadCell(KSpreadFilterProperty property) {
+KoFilter::ConversionStatus ExcelWorker::startSpreadCell(KSpreadFilterProperty property) {
return KoFilter::OK;
}
*/
diff --git a/filters/kspread/excel/excelexport.h b/filters/kspread/excel/excelexport.h
index 029cdac1..e4b6b499 100644
--- a/filters/kspread/excel/excelexport.h
+++ b/filters/kspread/excel/excelexport.h
@@ -16,20 +16,20 @@ public:
ExcelExport(KoFilter *parent, const char*name, const TQStringList&);
virtual ~ExcelExport() {}
- virtual KoFilter::ConversiontqStatus convert(const TQCString& from, const TQCString& to);
+ virtual KoFilter::ConversionStatus convert(const TQCString& from, const TQCString& to);
};
class ExcelWorker : public KSpreadBaseWorker {
public:
// Implement those
- //KoFilter::ConversiontqStatus startDocument(KSpreadFilterProperty property);
- //KoFilter::ConversiontqStatus startInfoLog(KSpreadFilterProperty property);
- //KoFilter::ConversiontqStatus startInfoAuthor(KSpreadFilterProperty property);
- //KoFilter::ConversiontqStatus startInfoAbout(KSpreadFilterProperty property);
- //KoFilter::ConversiontqStatus startSpreadBook(KSpreadFilterProperty property);
- //KoFilter::ConversiontqStatus startSpreadSheet(KSpreadFilterProperty property);
- //KoFilter::ConversiontqStatus startSpreadCell(KSpreadFilterProperty property);
+ //KoFilter::ConversionStatus startDocument(KSpreadFilterProperty property);
+ //KoFilter::ConversionStatus startInfoLog(KSpreadFilterProperty property);
+ //KoFilter::ConversionStatus startInfoAuthor(KSpreadFilterProperty property);
+ //KoFilter::ConversionStatus startInfoAbout(KSpreadFilterProperty property);
+ //KoFilter::ConversionStatus startSpreadBook(KSpreadFilterProperty property);
+ //KoFilter::ConversionStatus startSpreadSheet(KSpreadFilterProperty property);
+ //KoFilter::ConversionStatus startSpreadCell(KSpreadFilterProperty property);
};
#endif
diff --git a/filters/kspread/excel/import/excelimport.cc b/filters/kspread/excel/import/excelimport.cc
index f1bade9e..75ee412a 100644
--- a/filters/kspread/excel/import/excelimport.cc
+++ b/filters/kspread/excel/import/excelimport.cc
@@ -33,7 +33,7 @@
#include <tqfile.h>
#include <tqmap.h>
#include <tqstring.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <kdebug.h>
#include <KoFilterChain.h>
@@ -107,7 +107,7 @@ ExcelImport::~ExcelImport()
delete d;
}
-KoFilter::ConversiontqStatus ExcelImport::convert( const TQCString& from, const TQCString& to )
+KoFilter::ConversionStatus ExcelImport::convert( const TQCString& from, const TQCString& to )
{
if ( from != "application/msexcel" )
return KoFilter::NotImplemented;
@@ -348,7 +348,7 @@ void ExcelImport::Private::processSheetForBody( Sheet* sheet, KoXmlWriter* xmlWr
xmlWriter->addAttribute( "table:name", string( sheet->name() ).string() );
xmlWriter->addAttribute( "table:print", "false" );
xmlWriter->addAttribute( "table:protected", "false" );
- xmlWriter->addAttribute( "table:style-name", TQString("ta%1").tqarg(sheetFormatIndex));
+ xmlWriter->addAttribute( "table:style-name", TQString("ta%1").arg(sheetFormatIndex));
sheetFormatIndex++;
unsigned ci = 0;
@@ -397,7 +397,7 @@ void ExcelImport::Private::processSheetForStyle( Sheet* sheet, KoXmlWriter* xmlW
xmlWriter->startElement( "style:style" );
xmlWriter->addAttribute( "style:family", "table" );
xmlWriter->addAttribute( "style:master-page-name", "Default" );
- xmlWriter->addAttribute( "style:name", TQString("ta%1").tqarg(sheetFormatIndex) );
+ xmlWriter->addAttribute( "style:name", TQString("ta%1").arg(sheetFormatIndex) );
sheetFormatIndex++;
xmlWriter->startElement( "style:table-properties" );
@@ -450,7 +450,7 @@ void ExcelImport::Private::processColumnForBody( Column* column, int repeat, KoX
xmlWriter->addAttribute( "table:default-style-name", "Default" );
xmlWriter->addAttribute( "table:visibility", column->visible() ? "visible" : "collapse" );
if(repeat > 1) xmlWriter->addAttribute( "table:number-columns-repeated", repeat );
- xmlWriter->addAttribute( "table:style-name", TQString("co%1").tqarg(columnFormatIndex) );
+ xmlWriter->addAttribute( "table:style-name", TQString("co%1").arg(columnFormatIndex) );
columnFormatIndex++;
xmlWriter->endElement(); // table:table-column
@@ -463,12 +463,12 @@ void ExcelImport::Private::processColumnForStyle( Column* column, int /*repeat*/
xmlWriter->startElement( "style:style" );
xmlWriter->addAttribute( "style:family", "table-column" );
- xmlWriter->addAttribute( "style:name", TQString("co%1").tqarg(columnFormatIndex) );
+ xmlWriter->addAttribute( "style:name", TQString("co%1").arg(columnFormatIndex) );
columnFormatIndex++;
xmlWriter->startElement( "style:table-column-properties" );
xmlWriter->addAttribute( "fo:break-before", "auto" );
- xmlWriter->addAttribute( "style:column-width", TQString("%1in").tqarg(column->width()/27) );
+ xmlWriter->addAttribute( "style:column-width", TQString("%1in").arg(column->width()/27) );
xmlWriter->endElement(); // style:table-column-properties
xmlWriter->endElement(); // style:style
@@ -494,7 +494,7 @@ void ExcelImport::Private::processRowForBody( Row* row, int /*repeat*/, KoXmlWri
xmlWriter->startElement( "table:table-row" );
xmlWriter->addAttribute( "table:visibility", row->visible() ? "visible" : "collapse" );
- xmlWriter->addAttribute( "table:style-name", TQString("ro%1").tqarg(rowFormatIndex) );
+ xmlWriter->addAttribute( "table:style-name", TQString("ro%1").arg(rowFormatIndex) );
rowFormatIndex++;
for( int i = 0; i <= lastCol; i++ )
@@ -530,12 +530,12 @@ void ExcelImport::Private::processRowForStyle( Row* row, int repeat, KoXmlWriter
xmlWriter->startElement( "style:style" );
xmlWriter->addAttribute( "style:family", "table-row" );
if(repeat > 1) xmlWriter->addAttribute( "table:number-rows-repeated", repeat );
- xmlWriter->addAttribute( "style:name", TQString("ro%1").tqarg(rowFormatIndex) );
+ xmlWriter->addAttribute( "style:name", TQString("ro%1").arg(rowFormatIndex) );
rowFormatIndex++;
xmlWriter->startElement( "style:table-row-properties" );
xmlWriter->addAttribute( "fo:break-before", "auto" );
- xmlWriter->addAttribute( "style:row-height", TQString("%1pt").tqarg(row->height()) );
+ xmlWriter->addAttribute( "style:row-height", TQString("%1pt").arg(row->height()) );
xmlWriter->endElement(); // style:table-row-properties
xmlWriter->endElement(); // style:style
@@ -703,7 +703,7 @@ void ExcelImport::Private::processCellForStyle( Cell* cell, KoXmlWriter* xmlWrit
const UString& valueFormat = format.valueFormat();
if( !valueFormat.isEmpty() )
{
- refName = TQString("N%1").tqarg(cell->formatIndex());
+ refName = TQString("N%1").arg(cell->formatIndex());
TQString numformat = string( valueFormat ).string();
processValueFormat( numformat, refName, xmlWriter );
}
@@ -717,7 +717,7 @@ void ExcelImport::Private::processCellForStyle( Cell* cell, KoXmlWriter* xmlWrit
// now the real table-cell
xmlWriter->startElement( "style:style" );
xmlWriter->addAttribute( "style:family", "table-cell" );
- xmlWriter->addAttribute( "style:name", TQString("ce%1").tqarg( cell->formatIndex() ) );
+ xmlWriter->addAttribute( "style:name", TQString("ce%1").arg( cell->formatIndex() ) );
if( !refName.isEmpty() )
xmlWriter->addAttribute( "style:data-style-name", refName );
@@ -759,7 +759,7 @@ void ExcelImport::Private::processFormat( const Format* format, KoXmlWriter* xml
if( !xmlWriter ) return;
const FormatFont& font = format->font();
- const FormatAlignment& align = format->tqalignment();
+ const FormatAlignment& align = format->alignment();
const FormatBackground& back = format->background();
const FormatBorders& borders = format->borders();
@@ -792,7 +792,7 @@ void ExcelImport::Private::processFormat( const Format* format, KoXmlWriter* xml
if( !font.fontFamily().isEmpty() )
xmlWriter->addAttribute( "style:font-name", string(font.fontFamily()).string() );
- xmlWriter->addAttribute( "fo:font-size", TQString("%1pt").tqarg(font.fontSize()) );
+ xmlWriter->addAttribute( "fo:font-size", TQString("%1pt").arg(font.fontSize()) );
xmlWriter->addAttribute( "fo:color", convertColor( font.color() ) );
diff --git a/filters/kspread/excel/import/excelimport.h b/filters/kspread/excel/import/excelimport.h
index 5b733733..84729b4d 100644
--- a/filters/kspread/excel/import/excelimport.h
+++ b/filters/kspread/excel/import/excelimport.h
@@ -35,7 +35,7 @@ public:
ExcelImport ( TQObject *parent, const char* name, const TQStringList& );
virtual ~ExcelImport();
- virtual KoFilter::ConversiontqStatus convert( const TQCString& from, const TQCString& to );
+ virtual KoFilter::ConversionStatus convert( const TQCString& from, const TQCString& to );
private:
class Private;
diff --git a/filters/kspread/excel/sidewinder/excel.cpp b/filters/kspread/excel/sidewinder/excel.cpp
index 8155bca5..2a3a6247 100644
--- a/filters/kspread/excel/sidewinder/excel.cpp
+++ b/filters/kspread/excel/sidewinder/excel.cpp
@@ -185,7 +185,7 @@ static Value errorAsValue( int errorCode )
class EString::Private
{
public:
- bool tqunicode;
+ bool unicode;
bool richText;
UString str;
unsigned size;
@@ -194,7 +194,7 @@ public:
EString::EString()
{
d = new EString::Private();
- d->tqunicode = false;
+ d->unicode = false;
d->richText = false;
d->str = UString::null;
d->size = 0;
@@ -208,7 +208,7 @@ EString::EString( const EString& es )
EString& EString::operator=( const EString& es )
{
- d->tqunicode = es.d->tqunicode;
+ d->unicode = es.d->unicode;
d->richText = es.d->richText;
d->size = es.d->size;
d->str = es.d->str;
@@ -220,14 +220,14 @@ EString::~EString()
delete d;
}
-bool EString::tqunicode() const
+bool EString::unicode() const
{
- return d->tqunicode;
+ return d->unicode;
}
void EString::setUnicode( bool u )
{
- d->tqunicode = u;
+ d->unicode = u;
}
bool EString::richText() const
@@ -271,7 +271,7 @@ EString EString::fromUnicodeString( const void* p, bool longString, unsigned /*
unsigned char flag = data[ offset ];
offset++; // for flag (1 byte)
- bool tqunicode = flag & 0x01;
+ bool unicode = flag & 0x01;
bool richText = flag & 0x08;
unsigned formatRuns = 0;
@@ -283,10 +283,10 @@ EString EString::fromUnicodeString( const void* p, bool longString, unsigned /*
// find out total bytes used in this string
unsigned size = offset + len; // string data
- if( tqunicode ) size += len; // because tqunicode takes 2-bytes char
+ if( unicode ) size += len; // because unicode takes 2-bytes char
if( richText ) size += (formatRuns*4);
- if( !tqunicode )
+ if( !unicode )
{
char* buffer = new char[ len+1 ];
memcpy( buffer, data + offset, len );
@@ -303,7 +303,7 @@ EString EString::fromUnicodeString( const void* p, bool longString, unsigned /*
}
EString result;
- result.setUnicode( tqunicode );
+ result.setUnicode( unicode );
result.setRichText( richText );
result.setSize( size );
result.setStr( str );
@@ -351,14 +351,14 @@ EString EString::fromSheetName( const void* p, unsigned datasize )
unsigned len = data[0];
unsigned flag = data[1];
- bool tqunicode = flag & 1;
+ bool unicode = flag & 1;
if( len > datasize-2 ) len = datasize-2;
if( len == 0 ) return EString();
unsigned offset = 2;
- if( !tqunicode )
+ if( !unicode )
{
char* buffer = new char[ len+1 ];
memcpy( buffer, data + offset, len );
@@ -376,7 +376,7 @@ EString EString::fromSheetName( const void* p, unsigned datasize )
}
EString result;
- result.setUnicode( tqunicode );
+ result.setUnicode( unicode );
result.setRichText( richText );
result.setSize( datasize );
result.setStr( str );
@@ -2012,7 +2012,7 @@ void BoundSheetRecord::setData( unsigned size, const unsigned char* data )
d->visibility = data[4];
d->type = data[5];
- /* FIXME: it turned out that sheet name is not normal tqunicode string
+ /* FIXME: it turned out that sheet name is not normal unicode string
where the first two bytes specifies string length, but instead
only the first specifies it.
the next byte could be correctly interpreted as flag.
@@ -5113,31 +5113,31 @@ bool ExcelReader::load( Workbook* workbook, const char* filename )
format.setFont( convertFont( xf.fontIndex() ) );
- FormatAlignment tqalignment;
+ FormatAlignment alignment;
switch( xf.horizontalAlignment() )
{
case XFRecord::Left:
- tqalignment.setAlignX( Format::Left ); break;
+ alignment.setAlignX( Format::Left ); break;
case XFRecord::Right:
- tqalignment.setAlignX( Format::Right ); break;
+ alignment.setAlignX( Format::Right ); break;
case XFRecord::Centered:
- tqalignment.setAlignX( Format::Center ); break;
+ alignment.setAlignX( Format::Center ); break;
default: break;
// FIXME still unsupported: Repeat, Justified, Filled, Distributed
};
switch( xf.verticalAlignment() )
{
case XFRecord::Top:
- tqalignment.setAlignY( Format::Top ); break;
+ alignment.setAlignY( Format::Top ); break;
case XFRecord::VCentered:
- tqalignment.setAlignY( Format::Middle ); break;
+ alignment.setAlignY( Format::Middle ); break;
case XFRecord::Bottom:
- tqalignment.setAlignY( Format::Bottom ); break;
+ alignment.setAlignY( Format::Bottom ); break;
default: break;
// FIXME still unsupported: Justified, Distributed
}
- tqalignment.setWrap( xf.textWrap() );
- format.tqsetAlignment( tqalignment );
+ alignment.setWrap( xf.textWrap() );
+ format.setAlignment( alignment );
FormatBorders borders;
@@ -5929,31 +5929,31 @@ Format ExcelReader::convertFormat( unsigned xfIndex )
format.setFont( convertFont( xf.fontIndex() ) );
- FormatAlignment tqalignment;
+ FormatAlignment alignment;
switch( xf.horizontalAlignment() )
{
case XFRecord::Left:
- tqalignment.setAlignX( Format::Left ); break;
+ alignment.setAlignX( Format::Left ); break;
case XFRecord::Right:
- tqalignment.setAlignX( Format::Right ); break;
+ alignment.setAlignX( Format::Right ); break;
case XFRecord::Centered:
- tqalignment.setAlignX( Format::Center ); break;
+ alignment.setAlignX( Format::Center ); break;
default: break;
// FIXME still unsupported: Repeat, Justified, Filled, Distributed
};
switch( xf.verticalAlignment() )
{
case XFRecord::Top:
- tqalignment.setAlignY( Format::Top ); break;
+ alignment.setAlignY( Format::Top ); break;
case XFRecord::VCentered:
- tqalignment.setAlignY( Format::Middle ); break;
+ alignment.setAlignY( Format::Middle ); break;
case XFRecord::Bottom:
- tqalignment.setAlignY( Format::Bottom ); break;
+ alignment.setAlignY( Format::Bottom ); break;
default: break;
// FIXME still unsupported: Justified, Distributed
}
- tqalignment.setWrap( xf.textWrap() );
- format.tqsetAlignment( tqalignment );
+ alignment.setWrap( xf.textWrap() );
+ format.setAlignment( alignment );
FormatBorders borders;
diff --git a/filters/kspread/excel/sidewinder/format.cpp b/filters/kspread/excel/sidewinder/format.cpp
index 29481fd0..8ce69f24 100644
--- a/filters/kspread/excel/sidewinder/format.cpp
+++ b/filters/kspread/excel/sidewinder/format.cpp
@@ -271,7 +271,7 @@ FormatAlignment& FormatAlignment::operator=( const FormatAlignment& align )
return assign( align );
}
-// assign from another tqalignment
+// assign from another alignment
FormatAlignment& FormatAlignment::assign( const FormatAlignment& align )
{
d->null = align.isNull();
@@ -398,7 +398,7 @@ FormatBackground& FormatBackground::operator=( const FormatBackground& backgroun
return assign( background );
}
-// assign from another tqalignment
+// assign from another alignment
FormatBackground& FormatBackground::assign( const FormatBackground& background )
{
d->null = background.isNull();
@@ -498,7 +498,7 @@ FormatBorders& FormatBorders::operator=( const FormatBorders& border )
return assign( border );
}
-// assign from another tqalignment
+// assign from another alignment
FormatBorders& FormatBorders::assign( const FormatBorders& border )
{
d->null = border.isNull();
@@ -581,7 +581,7 @@ class Format::Private
{
public:
FormatFont font;
- FormatAlignment tqalignment;
+ FormatAlignment alignment;
FormatBorders borders;
FormatBackground background;
UString valueFormat;
@@ -617,7 +617,7 @@ Format& Format::operator=( const Format& f )
Format& Format::assign( const Format& f )
{
d->font = f.font();
- d->tqalignment = f.tqalignment();
+ d->alignment = f.alignment();
d->borders = f.borders();
d->valueFormat = f.valueFormat();
d->background = f.background();
@@ -626,7 +626,7 @@ Format& Format::assign( const Format& f )
bool Format::isNull() const
{
- return d->font.isNull() && d->tqalignment.isNull() && d->borders.isNull();
+ return d->font.isNull() && d->alignment.isNull() && d->borders.isNull();
}
FormatFont& Format::font() const
@@ -639,14 +639,14 @@ void Format::setFont( const FormatFont& font )
d->font = font;
}
-FormatAlignment& Format::tqalignment() const
+FormatAlignment& Format::alignment() const
{
- return d->tqalignment;
+ return d->alignment;
}
-void Format::tqsetAlignment( const FormatAlignment& tqalignment )
+void Format::setAlignment( const FormatAlignment& alignment )
{
- d->tqalignment = tqalignment;
+ d->alignment = alignment;
}
FormatBorders& Format::borders() const
@@ -682,8 +682,8 @@ void Format::setValueFormat( const UString& valueFormat )
// merge f into current format
Format& Format::apply( const Format& f )
{
- if( !f.tqalignment().isNull() )
- tqalignment() = f.tqalignment();
+ if( !f.alignment().isNull() )
+ alignment() = f.alignment();
if( !f.font().isNull() )
font() = f.font();
if( !f.borders().isNull() )
@@ -700,7 +700,7 @@ bool Format::operator==(const Format& format) const
{
return
d->font == format.d->font &&
- d->tqalignment == format.d->tqalignment &&
+ d->alignment == format.d->alignment &&
d->borders == format.d->borders &&
d->background == format.d->background &&
d->valueFormat == format.d->valueFormat;
@@ -710,7 +710,7 @@ bool Format::operator!=(const Format& format) const
{
return
d->font != format.d->font ||
- d->tqalignment != format.d->tqalignment ||
+ d->alignment != format.d->alignment ||
d->borders != format.d->borders ||
d->background != format.d->background ||
d->valueFormat != format.d->valueFormat;
diff --git a/filters/kspread/excel/sidewinder/format.h b/filters/kspread/excel/sidewinder/format.h
index dcadc1c2..acb566a5 100644
--- a/filters/kspread/excel/sidewinder/format.h
+++ b/filters/kspread/excel/sidewinder/format.h
@@ -266,9 +266,9 @@ private:
/**
- * Defines tqalignment information for cell format.
+ * Defines alignment information for cell format.
*
- * Class FormatAlignment defines the horizontal and vertical tqalignment
+ * Class FormatAlignment defines the horizontal and vertical alignment
* for the text inside a cell.
*
*/
@@ -278,37 +278,37 @@ class FormatAlignment
public:
/**
- * Creates a default tqalignment information.
+ * Creates a default alignment information.
*/
FormatAlignment();
/**
- * Destroys the tqalignment information
+ * Destroys the alignment information
*/
~FormatAlignment();
/**
- * Creates a copy of tqalignment information.
+ * Creates a copy of alignment information.
*/
FormatAlignment( const FormatAlignment& );
/**
- * Assigns from another tqalignment information.
+ * Assigns from another alignment information.
*/
FormatAlignment& operator=( const FormatAlignment& );
/**
- * Assigns from another tqalignment information.
+ * Assigns from another alignment information.
*/
FormatAlignment& assign( const FormatAlignment& );
/**
- * Returns true if it is a default tqalignment information.
+ * Returns true if it is a default alignment information.
*/
bool isNull() const;
/**
- * Returns horizontal tqalignment. Possible values are
+ * Returns horizontal alignment. Possible values are
* Format::Left, Format::Right and Format::Center.
*
* \sa setAlignX
@@ -316,14 +316,14 @@ public:
unsigned alignX() const;
/**
- * Sets the horizontal tqalignment.
+ * Sets the horizontal alignment.
*
* \sa alignX
*/
void setAlignX( unsigned xa );
/**
- * Returns horizontal tqalignment. Possible values are
+ * Returns horizontal alignment. Possible values are
* Format::Top, Format::Middle and Format::Bottom.
*
* \sa setAlignY
@@ -331,7 +331,7 @@ public:
unsigned alignY() const;
/**
- * Sets the horizontal tqalignment.
+ * Sets the horizontal alignment.
*
* \sa alignY
*/
@@ -380,12 +380,12 @@ public:
void setRotationAngle( unsigned r );
/**
- * Returns true if this tqalignment is equal to f; otherwise returns false.
+ * Returns true if this alignment is equal to f; otherwise returns false.
*/
bool operator==(const FormatAlignment& f) const;
/**
- * Returns true if this tqalignment is not equal to f; otherwise returns false.
+ * Returns true if this alignment is not equal to f; otherwise returns false.
*/
bool operator!=(const FormatAlignment& f) const;
@@ -683,14 +683,14 @@ public:
void setFont( const FormatFont& font );
/**
- * Returns a constant reference to the tqalignment information of this format.
+ * Returns a constant reference to the alignment information of this format.
*/
- FormatAlignment& tqalignment() const;
+ FormatAlignment& alignment() const;
/**
- * Sets new tqalignment information for this format.
+ * Sets new alignment information for this format.
*/
- void tqsetAlignment( const FormatAlignment& tqalignment );
+ void setAlignment( const FormatAlignment& alignment );
/**
* Returns a reference to the borders information of this format.
diff --git a/filters/kspread/excel/sidewinder/ustring.cpp b/filters/kspread/excel/sidewinder/ustring.cpp
index b26ee196..304fed18 100644
--- a/filters/kspread/excel/sidewinder/ustring.cpp
+++ b/filters/kspread/excel/sidewinder/ustring.cpp
@@ -39,7 +39,7 @@ UString UString::null;
static char *statBuffer = 0L;
UChar::UChar(const UCharReference &c)
- : uc( c.tqunicode() )
+ : uc( c.unicode() )
{
}
@@ -579,7 +579,7 @@ bool Swinder::operator<(const UString& s1, const UString& s2)
l++;
}
if (l < lmin)
- return (c1->tqunicode() < c2->tqunicode());
+ return (c1->unicode() < c2->unicode());
return (l1 < l2);
}
diff --git a/filters/kspread/excel/sidewinder/ustring.h b/filters/kspread/excel/sidewinder/ustring.h
index 1c4f2bc5..3f41867b 100644
--- a/filters/kspread/excel/sidewinder/ustring.h
+++ b/filters/kspread/excel/sidewinder/ustring.h
@@ -68,7 +68,7 @@ namespace Swinder {
/**
* @return the 16 bit Unicode value of the character
*/
- unsigned short tqunicode() const { return uc; }
+ unsigned short unicode() const { return uc; }
public:
/**
* A static instance of UChar(0).
@@ -120,7 +120,7 @@ namespace Swinder {
/**
* @return Unicode value.
*/
- unsigned short tqunicode() const { return ref().uc; }
+ unsigned short unicode() const { return ref().uc; }
/**
* @return Lower byte.
*/
diff --git a/filters/kspread/excel/sidewinder/excel.h b/filters/kspread/excel/sidewinder/excel.h
index 8cbdfd53..5221b518 100644
--- a/filters/kspread/excel/sidewinder/excel.h
+++ b/filters/kspread/excel/sidewinder/excel.h
@@ -36,7 +36,7 @@ enum { UnknownExcel = 0, Excel95, Excel97, Excel2000 };
class Record;
// rich-text, tqunicode, far-east support Excel string
class EString
{
@@ -50,7 +50,7 @@ public:
~EString();
- bool tqunicode() const;
+ bool unicode() const;
void setUnicode( bool u );
@@ -2805,17 +2805,17 @@ public:
Distributed };
/**
- * Gets the horizontal tqalignment, e.g Left.
+ * Gets the horizontal alignment, e.g Left.
*/
unsigned horizontalAlignment() const;
/**
- * Sets the horizontal tqalignment, e.g Left.
+ * Sets the horizontal alignment, e.g Left.
*/
void setHorizontalAlignment( unsigned ha );
/**
- * Returns human-readable string representation of the horizontal tqalignment.
+ * Returns human-readable string representation of the horizontal alignment.
For example, XFRecord::Left will return "Left".
*/
const char* horizontalAlignmentAsString() const;
@@ -2828,21 +2828,21 @@ public:
VDistributed = 4 };
/**
- * Gets the vertical tqalignment, e.g Bottom.
+ * Gets the vertical alignment, e.g Bottom.
*
* \sa setVerticalAlignment
*/
unsigned verticalAlignment() const;
/**
- * Sets the vertical tqalignment, e.g Top.
+ * Sets the vertical alignment, e.g Top.
*
* \sa verticalAlignment
*/
void setVerticalAlignment( unsigned va );
/**
- * Returns human-readable string representation of the vertical tqalignment.
+ * Returns human-readable string representation of the vertical alignment.
For example, XFRecord::Top will return "Top".
*/
const char* verticalAlignmentAsString() const;
@@ -36,7 +36,7 @@ enum { UnknownExcel = 0, Excel95, Excel97, Excel2000 };
class Record;
-// rich-text, tqunicode, far-east support Excel string
+// rich-text, unicode, far-east support Excel string
class EString
{
diff --git a/filters/kspread/excel/sidewinder/pole.cpp b/filters/kspread/excel/sidewinder/pole.cpp
index 38fe8cb5..e4090cd9 100644
--- a/filters/kspread/excel/sidewinder/pole.cpp
+++ b/filters/kspread/excel/sidewinder/pole.cpp
@@ -95,7 +95,7 @@ class DirEntry
{
public:
bool valid; // false if invalid (should be skipped)
- std::string name; // the name, not in tqunicode anymore
+ std::string name; // the name, not in unicode anymore
bool dir; // true if directory
unsigned long size; // size (not valid if directory)
unsigned long start; // starting block
@@ -116,7 +116,7 @@ class DirTree
int indexOf( DirEntry* e );
int parent( unsigned index );
std::string fullName( unsigned index );
- std::vector<unsigned> tqchildren( unsigned index );
+ std::vector<unsigned> children( unsigned index );
void load( unsigned char* buffer, unsigned len );
void save( unsigned char* buffer );
unsigned size();
@@ -509,11 +509,11 @@ int DirTree::indexOf( DirEntry* e )
int DirTree::parent( unsigned index )
{
// brute-force, basically we iterate for each entries, find its tqchildren
// and check if one of the tqchildren is 'index'
for( unsigned j=0; j<entryCount(); j++ )
{
- std::vector<unsigned> chi = tqchildren( j );
+ std::vector<unsigned> chi = children( j );
for( unsigned i=0; i<chi.size();i++ )
if( chi[i] == index )
return j;
@@ -577,8 +577,8 @@ DirEntry* DirTree::entry( const std::string& name, bool create )
for( it = names.begin(); it != names.end(); ++it )
{
- // find among the tqchildren of index
- std::vector<unsigned> chi = tqchildren( index );
+ // find among the children of index
+ std::vector<unsigned> chi = children( index );
unsigned child = 0;
for( unsigned i = 0; i < chi.size(); i++ )
{
@@ -593,7 +593,7 @@ DirEntry* DirTree::entry( const std::string& name, bool create )
if( child > 0 ) index = child;
else
{
// not found among tqchildren
if( !create ) return (DirEntry*)0;
// create a new entry
@@ -650,7 +650,7 @@ void dirtree_find_siblings( DirTree* dirtree, std::vector<unsigned>& result,
}
}
-std::vector<unsigned> DirTree::tqchildren( unsigned index )
+std::vector<unsigned> DirTree::children( unsigned index )
{
std::vector<unsigned> result;
@@ -1286,9 +1286,9 @@ std::list<std::string> Storage::entries( const std::string& path )
if( e && e->dir )
{
unsigned parent = dt->indexOf( e );
- std::vector<unsigned> tqchildren = dt->tqchildren( parent );
- for( unsigned i = 0; i < tqchildren.size(); i++ )
- result.push_back( dt->entry( tqchildren[i] )->name );
+ std::vector<unsigned> children = dt->children( parent );
+ for( unsigned i = 0; i < children.size(); i++ )
+ result.push_back( dt->entry( children[i] )->name );
}
return result;
@@ -509,11 +509,11 @@ int DirTree::indexOf( DirEntry* e )
int DirTree::parent( unsigned index )
{
- // brute-force, basically we iterate for each entries, find its tqchildren
- // and check if one of the tqchildren is 'index'
+ // brute-force, basically we iterate for each entries, find its children
+ // and check if one of the children is 'index'
for( unsigned j=0; j<entryCount(); j++ )
{
@@ -593,7 +593,7 @@ DirEntry* DirTree::entry( const std::string& name, bool create )
else
{
- // not found among tqchildren
+ // not found among children
if( !create ) return (DirEntry*)0;
// create a new entry